Learn R Programming

genridge (version 0.6-2)

trans.colors: Make Colors Transparent

Description

Takes a vector of colors (as color names or rgb hex values) and adds a specified alpha transparency to each.

Usage

trans.colors(col, alpha = 0.5, names = NULL)

Arguments

Value

A vector of color values of the form "#rrggbbaa"

Details

Colors (col) and alpha need not be of the same length. The shorter one is replicated to make them of the same length.

See Also

col2rgb, rgb,

Examples

Run this code
trans.colors(palette(), alpha=0.5)

# alpha can be vectorized
trans.colors(palette(), alpha=seq(0, 1, length=length(palette())))

# lengths need not match: shorter one is repeated as necessary
trans.colors(palette(), alpha=c(.1, .2))

trans.colors(colors()[1:20])

# single color, with various alphas
trans.colors("red", alpha=seq(0,1, length=5))
# assign names
trans.colors("red", alpha=seq(0,1, length=5), names=paste("red", 1:5, sep=""))

Run the code above in your browser using DataLab