Learn R Programming

genridge (version 0.5-0)

genridge-package: Generalized ridge trace plots for ridge regression

Description

The genridge package introduces generalizations of the standard univariate ridge trace plot used in ridge regression and related methods. These graphical methods show both bias and precision, by plotting the covariance ellipsoids of the estimated coefficients, rather than just the estimates themselves.

Arguments

docType

package

Details

ll{ Package: genridge Type: Package Version: 0.5-0 Date: 2011-08-22 License: GPL version 2 or newer LazyLoad: yes } Ridge regression models may be fit using the function ridge, which incorporates features of lm.ridge and simple.ridge. In particular, the shrinkage factors in ridge regression may be specified either in terms of the constant added to the diagonal of $X^T X$ matrix (lambda), or the equivalent number of degrees of freedom. More importantly, the ridge function also calculates and returns the associated covariance matrices of each of the ridge estimates. This provides the support for the main plotting functions in the package: plot.ridge: Bivariate ridge trace plots pairs.ridge: All pairwise bivariate ridge trace plots traceplot: Traditional univariate ridge trace plots

References

Friendly, M. (2011). The Generalized Ridge Trace Plot: Visualizing Bias and Precision. In preparation. Arthur E. Hoerl and Robert W. Kennard (1970). Ridge Regression: Biased Estimation for Nonorthogonal Problems, Technometrics, 12(1), pp. 55-67. Arthur E. Hoerl and Robert W. Kennard (1970). Ridge Regression: Applications to Nonorthogonal Problems Technometrics, 12(1), pp. 69-82.

See Also

lm.ridge, simple.ridge

Examples

Run this code
# see examples for ridge, etc.

Run the code above in your browser using DataLab