ridge,
which incorporates features of lm.ridge and
simple.ridge. In particular, the shrinkage
factors in ridge regression may be specified either in terms of
the constant added to the diagonal of $X^T X$ matrix (lambda),
or the equivalent number of degrees of freedom.
More importantly, the ridge function also calculates and
returns the associated covariance matrices of each of the ridge estimates.
This provides the support for the main plotting functions in the package:
plot.ridge: Bivariate ridge trace plots
pairs.ridge: All pairwise bivariate ridge trace plots
traceplot: Traditional univariate ridge trace plotslm.ridge,
simple.ridge