ridge,
which incorporates features of lm.ridge and
simple.ridge. In particular, the shrinkage
factors in ridge regression may be specified either in terms of
the constant added to the diagonal of $X^T X$ matrix (lambda),
or the equivalent number of degrees of freedom.
More importantly, the ridge function also calculates and
returns the associated covariance matrices of each of the ridge estimates.
This provides the support for the main plotting functions in the package:
plot.ridge: Bivariate ridge trace plots
pairs.ridge: All pairwise bivariate ridge trace plots
plot3d.ridge: 3D ridge trace plots
traceplot: Traditional univariate ridge trace plots
In addition, the function pca.ridge transforms the coefficients
and covariance matrices of a ridge object from predictor space to the
equivalent, but more interesting space of the PCA of $X^T X$ or the
SVD of X.
The main plotting functions also work for these objects,
of class c("ridge", "pcaridge").
Finally, the functions precision and vif.ridge
provide other useful measures and plots.lm.ridge,
simple.ridge